{% load i18n %}

<form id="aa-corpstats-corpsearch" role="search" action="{% url 'corpstat:search' %}" method="GET">
    <div class="input-group has-feedback has-search">
        <input
            class="form-control"
            type="text"
            name="search_string"
            value="{{ search_string }}"
            placeholder="{% translate "Search all corporations …" %}"
        >
    </div>
</form>
